Learn R Programming

scbursts (version 1.6)

bursts.remove_first_and_last: Remove the first and last burst from the list.

Description

Remove the first and last burst from the list.

Usage

bursts.remove_first_and_last(bursts)

Arguments

bursts

The list of all bursts

Value

A shorter list of bursts

Examples

Run this code
# NOT RUN {
infile <- system.file("extdata", "example1_tac.evt", package = "scbursts")
transitions <- evt.read(infile)
dwells <- evt.to_dwells(transitions)
dwells_c <- risetime.correct_gaussian(Tr=35.0052278, dwells, units="us")

bursts <- bursts.defined_by_tcrit(dwells_c, 100, units="ms")

# If there seem to be bad bursts at the ends
bursts <- bursts.remove_first_and_last(bursts)

# }

Run the code above in your browser using DataLab