evt.to_dwells: Calculate pulse lengths. Converts transition times to dwell durations.
Description
Calculate pulse lengths. Converts transition times to dwell durations.
Usage
evt.to_dwells(tables)
Arguments
tables
Either a single table or a list of tables with columns "states" and "times"
Value
A segment or a list of segments with one less row, where each row
represents pulse in state 0 (closed dwell) of duration 0.51231, instead
of the time at which the state transitioned.